<h1 align = "center">:rocket: Seaborn :facepunch:</h1>

---

- [Seaborn][0]
	- [1.管理图表样式][1]
	- [2.选择配色方案][2]
	- [3.可视化数据集的分布][3]
	- [4.可视化线性关系][4]
	- [5.绘制类别型数据][5]
	- [6.绘制网格图表][6]
	
http://seaborn.pydata.org/tutorial.html
---
[0]: http://nbviewer.jupyter.org/github/Jie-Yuan/2_DataMining/tree/master/1_DataExploration/3_Seaborn/
[1]: http://nbviewer.jupyter.org/github/Jie-Yuan/2_DataMining/blob/master/1_DataExploration/3_Seaborn/1_Controlling%20figure%20aesthetics.ipynb
[2]: http://nbviewer.jupyter.org/github/Jie-Yuan/2_DataMining/blob/master/1_DataExploration/3_Seaborn/2_Choosing%20color%20palettes.ipynb
[3]: http://nbviewer.jupyter.org/github/Jie-Yuan/2_DataMining/blob/master/1_DataExploration/3_Seaborn/3_Visualizing%20the%20distribution%20of%20a%20dataset.ipynb
[4]: http://nbviewer.jupyter.org/github/Jie-Yuan/2_DataMining/blob/master/1_DataExploration/3_Seaborn/4_Visualizing%20linear%20relationships.ipynb
[5]: http://nbviewer.jupyter.org/github/Jie-Yuan/2_DataMining/blob/master/1_DataExploration/3_Seaborn/5_Plotting%20with%20categorical%20data.ipynb
[6]: http://nbviewer.jupyter.org/github/Jie-Yuan/2_DataMining/blob/master/1_DataExploration/3_Seaborn/6_Structured%20grids.ipynb
